@@ -10,6 +10,7 @@
 
 #include "controlutil.h"
 #include "controlid.h"
+#include "compmanager.h"
 
 using namespace ARTICLE;
 
@@ -17,11 +18,10 @@ SearchToolBar::SearchToolBar() :
     SKELETON::ToolBar( ARTICLE::get_admin() )
 {
     // 検索バー    
-    get_searchbar()->append( *get_entry_search() );
+    get_searchbar()->append( *get_entry_search( CORE::COMP_SEARCH_ARTICLE ) );
     get_searchbar()->append( *get_button_close_searchbar() );
 
     pack_buttons();
-    add_search_mode( CONTROL::MODE_COMMON );
 }
 
 
