@@ -11,8 +11,10 @@
 
 #include "dbtree/interface.h"
 
+#include "config/globalconf.h"
+
 #include "cache.h"
-#include "global.h"
+#include "type.h"
 #include "command.h"
 
 using namespace BBSLIST;
@@ -28,7 +30,7 @@ BBSListViewMain::BBSListViewMain( const std::string& url,
 {
     set_label( "板一覧" );
 
-    set_expand_collapse( true );
+    set_open_only_onedir( CONFIG::get_open_one_category() );
 }
 
 
@@ -172,7 +174,7 @@ void BBSListViewMain::delete_view_impl()
         }
     }
 
-    delete_selected_rows();
+    get_treeview().delete_selected_rows();
 
     // etc.txt保存
     DBTREE::save_etc();
