@@ -26,6 +26,13 @@
 
 #include <fcntl.h>
 
+enum
+{
+    MAX_SAFE_PATH = 1024
+};
+
+std::string root_path;
+
 
 // 設定ファイル
 std::string CACHE::path_conf()
@@ -37,7 +44,7 @@ std::string CACHE::path_conf()
 // 旧設定ファイル
 std::string CACHE::path_conf_old()
 {
-    std::string home = getenv( "HOME" );
+    std::string home = MISC::getenv_limited( "HOME", MAX_SAFE_PATH );
 
     return home + "/.jdrc";
 }
@@ -65,22 +72,22 @@ std::string CACHE::path_passwd( const std::string& basename )
 
 
 // キャッシュルートの絶対パス
-// キャッシュ構造は navi2ch の上位互換なので path_cacheroot = "~/.navi2ch/" とすればnavi2chとキャッシュを共有できる
 std::string CACHE::path_root()
 {
-    std::string root;
+    if( root_path.empty() ){
 
-    if( getenv( "JD_CACHE" ) ) root = getenv( "JD_CACHE" );
-    else root = "~/.jd/";
+        const std::string jd_cache = MISC::getenv_limited( "JD_CACHE", MAX_SAFE_PATH );
+        root_path = jd_cache.empty() ? "~/.jd/" : jd_cache;
 
-    if( root[ root.length() -1 ] != '/' ) root = root + "/";
+        if( root_path[ root_path.length() -1 ] != '/' ) root_path = root_path + "/";
 
-    if( root[ 0 ] == '~' ){
-        std::string home = getenv( "HOME" );
-        root.replace( 0, 1, home );
+        if( root_path[ 0 ] == '~' ){
+            std::string home = MISC::getenv_limited( "HOME", MAX_SAFE_PATH );
+            root_path.replace( 0, 1, home );
+        }
     }
 
-    return root;
+    return root_path;
 }
 
 
@@ -127,11 +134,22 @@ std::string CACHE::path_etcboard()
 
 // ユーザーコマンド設定ファイル
 std::string CACHE::path_usrcmd()
+{
+    return CACHE::path_root() +  "usrcmd.xml";
+}
+
+std::string CACHE::path_usrcmd_old()
 {
     return CACHE::path_root() +  "usrcmd.txt";
 }
 
 
+// リンクフィルタ設定ファイル
+std::string CACHE::path_linkfilter()
+{
+    return CACHE::path_root() +  "linkfilter.xml";
+}
+
 
 // 履歴
 std::string CACHE::path_xml_history()
@@ -169,6 +187,13 @@ std::string CACHE::path_xml_history_close_old()
 }
 
 
+// View履歴
+std::string CACHE::path_xml_history_view()
+{
+    return CACHE::path_root() +  "hist_view.xml";
+}
+
+
 // 板移転情報
 std::string CACHE::path_movetable()
 {
@@ -317,12 +342,21 @@ std::string CACHE::path_img_abone_root()
 }
 
 
+//
+// ログのルートパス
+//
+std::string CACHE::path_logroot()
+{
+    return CACHE::path_root() + "log/";
+}
+
+
 //
 // 書き込みログ
 //
 std::string CACHE::path_postlog()
 {
-    return CACHE::path_root() +  "post.log";
+    return path_logroot() + "postlog";
 }
 
 
@@ -335,6 +369,14 @@ std::string CACHE::path_completion( int mode )
 }
 
 
+//
+// サウンドファイルのルートパス
+//
+std::string CACHE::path_sound_root()
+{
+    return CACHE::path_root() + "sound/";
+}
+
 
 //
 // 画像キャッシュファイルの名前
@@ -572,6 +614,20 @@ bool CACHE::mkdir_boardroot( const std::string& url )
 }
 
 
+//
+// ログのルートディレクトリをmkdir
+//
+bool CACHE::mkdir_logroot()
+{
+    // root
+    std::string path_logroot = CACHE::path_logroot();
+    if( ! CACHE::jdmkdir( path_logroot ) ){
+        MISC::ERRMSG( "can't create " + path_logroot );
+        return false;
+    }
+
+    return true;
+}
 
 
 size_t CACHE::load_rawdata( const std::string& path, std::string& str )
@@ -588,7 +644,7 @@ size_t CACHE::load_rawdata( const std::string& path, std::string& str )
 }
 
 
-size_t CACHE::load_rawdata( const std::string& path, char* data, size_t n )
+size_t CACHE::load_rawdata( const std::string& path, char* data, const size_t n )
 {
     size_t count = 0;
     std::ifstream fin;
@@ -602,14 +658,14 @@ size_t CACHE::load_rawdata( const std::string& path, char* data, size_t n )
 }
 
 
-size_t CACHE::save_rawdata( const std::string& path, const std::string& str, bool append )
+size_t CACHE::save_rawdata( const std::string& path, const std::string& str, const bool append )
 {
     return save_rawdata( path, str.c_str(), str.length(), append );
 }
 
 
 
-size_t CACHE::save_rawdata( const std::string& path, const char* data, size_t n, bool append )
+size_t CACHE::save_rawdata( const std::string& path, const char* data, size_t n, const bool append )
 {
     size_t count = 0;
     size_t byte = 0;
@@ -645,7 +701,7 @@ size_t CACHE::save_rawdata( const std::string& path, const char* data, size_t n,
 }
 
 
-long CACHE::file_exists( const std::string& path )
+const int CACHE::file_exists( const std::string& path )
 {
     struct stat buf_stat;
 
@@ -654,6 +710,7 @@ long CACHE::file_exists( const std::string& path )
 
     if( S_ISREG( buf_stat.st_mode ) ) return EXIST_FILE;
     if( S_ISDIR( buf_stat.st_mode ) ) return EXIST_DIR;
+    if( S_ISFIFO( buf_stat.st_mode ) ) return EXIST_FIFO;
 
     return EXIST;
 }
@@ -694,7 +751,7 @@ bool CACHE::jdmkdir( const std::string& path )
     
     if( path.find( "~/" ) == 0 ){
 
-        std::string homedir = getenv( "HOME" );
+        std::string homedir = MISC::getenv_limited( "HOME", MAX_SAFE_PATH );
         if( homedir.empty() ) return false;
 
         target = homedir + path.substr( 2 );
@@ -858,7 +915,7 @@ void CACHE::add_filter_to_diag( Gtk::FileChooserDialog& diag, const int type )
 std::string CACHE::open_load_diag( Gtk::Window* parent, const std::string& open_path, const int type )
 {
     std::string dir = MISC::get_dir( open_path );
-    if( dir.empty() ) dir = getenv( "HOME" );
+    if( dir.empty() ) dir = MISC::getenv_limited( "HOME", MAX_SAFE_PATH );
 
     SKELETON::FileDiag diag( parent, "ファイルを開く", Gtk::FILE_CHOOSER_ACTION_OPEN );
 
@@ -892,7 +949,15 @@ std::string CACHE::open_save_diag( Gtk::Window* parent, const std::string& dir,
 #endif
 
     SKELETON::FileDiag diag( parent, "保存先選択", Gtk::FILE_CHOOSER_ACTION_SAVE );
-    diag.set_current_folder( dir );
+    if( dir.empty() )
+    {
+        const std::string home = MISC::getenv_limited( "HOME", MAX_SAFE_PATH );
+        if( ! home.empty() ) diag.set_current_folder( home );
+    }
+    else
+    {
+        diag.set_current_folder( dir );
+    }
     diag.set_current_name( name );
     add_filter_to_diag( diag, type );
 
