@@ -139,6 +139,9 @@ namespace CONFIG
         // bbsmenu.htmlの内にあるリンクは全て板とみなす
         bool use_link_as_board;
 
+        // 板移転時に確認ダイアログを表示する
+        bool show_movediag;
+
         // スレタイ検索用メニュータイトルアドレス
         std::string menu_search_title;
         std::string url_search_title;
@@ -150,6 +153,10 @@ namespace CONFIG
         std::string menu_search_web;
         std::string url_search_web;
 
+        // p2 書き込み用アドレス
+        std::string url_writep2;
+        std::string url_resp2;
+
         // 色
         std::vector< std::string > str_color;
 
@@ -171,6 +178,9 @@ namespace CONFIG
         // スレ一覧でインクリメント検索をする
         bool inc_search_board;
 
+        // スレ一覧でdeleteを押したときに確認ダイアログを表示する
+        bool show_deldiag;
+
         // ツリービューのスクロール量(マウスホイール上下・行数)
         int tree_scroll_size;
 
@@ -201,6 +211,9 @@ namespace CONFIG
         // 板一覧でカテゴリを常にひとつだけ開く
         bool open_one_category;
 
+        // お気に入りでカテゴリを常にひとつだけ開く
+        bool open_one_favorite;
+
         // 書き込み時に書き込み確認ダイアログを出さない
         bool always_write_ok;
 
@@ -271,9 +284,6 @@ namespace CONFIG
         // ユーザーコマンドで選択できない項目を非表示にする
         bool hide_usrcmd;
 
-        // 指定した数よりもユーザーコマンドが多い場合はサブメニュー化する
-        int max_show_usrcmd;
-
         // スレビューで再読み込みボタンを押したときに全タブを更新する
         bool reload_allthreads;
 
@@ -317,6 +327,9 @@ namespace CONFIG
         // 右ペーンが空の時にサイドバーを閉じるか
         bool expand_sidebar;
 
+        // 3ペーン時にスレ一覧やスレビューを最大化するか
+        bool expand_rpane;
+
 #ifdef HAVE_MIGEMO_H
         // migemo-dictの場所
         std::string migemodict_path;
