@@ -75,6 +75,10 @@ namespace CONFIG
     // bbsmenu.html内にあるリンクは全て板とみなす
     const bool use_link_as_board();
 
+    // 板移転時に確認ダイアログを表示する
+    const bool get_show_movediag();
+    void set_show_movediag( const bool show );
+
     // スレタイ検索用メニュータイトルアドレス
     const std::string& get_menu_search_title();
     const std::string& get_url_search_title();
@@ -86,6 +90,10 @@ namespace CONFIG
     const std::string& get_menu_search_web();
     const std::string& get_url_search_web();
 
+    // p2 書き込み用アドレス
+    const std::string& get_url_writep2();
+    const std::string& get_url_resp2();
+
     // 2ch にアクセスするときのエージェント名
     const std::string& get_agent_for2ch();
 
@@ -200,6 +208,10 @@ namespace CONFIG
     // スレ一覧でインクリメント検索をする
     const bool get_inc_search_board();
 
+    // スレ一覧でdeleteを押したときに確認ダイアログを表示する
+    const bool get_show_deldiag();
+    void set_show_deldiag( const bool show );
+
     // ツリービューのスクロール量(マウスホイール上下・行数)
     const int get_tree_scroll_size();
 
@@ -235,6 +247,9 @@ namespace CONFIG
     // 板一覧でカテゴリを常にひとつだけ開く
     const bool get_open_one_category();
 
+    // お気に入りでカテゴリを常にひとつだけ開く
+    const bool get_open_one_favorite();
+
     // 書き込み時に書き込み確認ダイアログを出すかどうか
     const bool get_always_write_ok();
     void set_always_write_ok( bool write_ok );
@@ -311,9 +326,7 @@ namespace CONFIG
 
     // ユーザーコマンドで選択できない項目を非表示にする
     const bool get_hide_usrcmd();
-
-    // 指定した数よりもユーザーコマンドが多い場合はサブメニュー化する
-    const int get_max_show_usrcmd();
+    void set_hide_usrcmd( bool hide );
 
     // スレビューで再読み込みボタンを押したときに全タブを更新する
     const bool get_reload_allthreads();
@@ -364,6 +377,9 @@ namespace CONFIG
     // 右ペーンが空の時にサイドバーを閉じるか
     const bool get_expand_sidebar();
 
+    // 3ペーン時にスレ一覧やスレビューを最大化するか
+    const bool get_expand_rpane();
+
 #ifdef HAVE_MIGEMO_H
     // migemo-dictの場所
     const std::string& get_migemodict_path();
