@@ -126,6 +126,9 @@ namespace DBTREE
         // 実況時の更新間隔(秒)
         time_t m_live_sec;
 
+        // 最終アクセス時刻
+        time_t m_last_access_time;
+
         // 最大レス数
         int m_number_max_res;
 
@@ -144,8 +147,9 @@ namespace DBTREE
         // クッキー, 書き込み時に必要
         std::list< std::string > m_list_cookies_for_write;
 
-        // hana, 2ch書き込み時に必要
-        std::string m_hana_for_write;   
+        // 書き込み時に必要なキーワード( hana=mogera や suka=pontan など )
+        // 書き込み時のメッセージに付加する
+        std::string m_keyword_for_write;   
 
         // basic 認証用の「ユーザID:パスワード」の組
         std::string m_basicauth;
@@ -249,9 +253,14 @@ namespace DBTREE
         const std::list< std::string >& list_cookies_for_write() { return m_list_cookies_for_write; }
         void set_list_cookies_for_write( const std::list< std::string >& list_cookies ){ m_list_cookies_for_write = list_cookies; }
 
-        // hana
-        const std::string& hana_for_write() { return m_hana_for_write; }
-        void set_hana_for_write( const std::string& hana ){ m_hana_for_write = hana; }
+        // 書き込み時に必要なキーワード( hana=mogera や suka=pontan など )
+        // 書き込み時のメッセージに付加する
+        const std::string& get_keyword_for_write() const { return m_keyword_for_write; }
+        void set_keyword_for_write( const std::string& keyword ){ m_keyword_for_write = keyword; }
+
+        // 書き込み時に必要なキーワード( hana=mogera や suka=pontan など )を
+        // 確認画面のhtmlから解析する      
+        virtual void analyze_keyword_for_write( const std::string& html ){}
 
         // basic認証
         const std::string& get_basicauth() const { return m_basicauth; }
@@ -261,15 +270,15 @@ namespace DBTREE
         // url がスレッドのURLで無い時はempty()が返る
         // もしurlが移転前の旧ホストのものだったら対応するarticlebaseクラスに旧ホスト名を知らせる
         // (例) url =  "http://www.hoge2ch.net/test/read.cgi/hogeboard/12345/12-15"のとき、
-        // "http://www.hoge2ch.net/hogeboard/dat/12345.dat",  num_from = 12, num_to = 15
-        const std::string url_dat( const std::string& url, int& num_from, int& num_to ); 
+        // "http://www.hoge2ch.net/hogeboard/dat/12345.dat",  num_from = 12, num_to = 15, num_str = 12-15
+        virtual const std::string url_dat( const std::string& url, int& num_from, int& num_to, std::string& num_str ); 
 
         // スレの url を read.cgi型のurlに変換
         // url がスレッドのURLで無い時はempty()が返る
         // num_from と num_to が 0 で無い時はスレ番号を付ける
         // (例) "http://www.hoge2ch.net/hogeboard/dat/12345.dat",  num_from = 12, num_to = 15 のとき
         // "http://www.hoge2ch.net/test/read.cgi/hogeboard/12345/12-15"
-        virtual const std::string url_readcgi( const std::string& url, int num_from, int num_to );
+        const std::string url_readcgi( const std::string& url, int num_from, int num_to );
 
         // subject.txt の URLを取得
         // (例) "http://www.hoge2ch.net/hogeboard/subject.txt"
@@ -297,7 +306,7 @@ namespace DBTREE
 
         // read.cgi のURLのパスを返す
         // (例) "http://www.hoge2ch.net/test/read.cgi/hogeboard/12345" なら "/test/read.cgi/hogeboard/"
-        virtual const std::string url_readcgipath();
+        const std::string url_readcgipath();
 
         // bbscgi のURLのベースアドレス
         const std::string url_bbscgibase();
@@ -392,6 +401,9 @@ namespace DBTREE
         const time_t get_live_sec() const{ return m_live_sec; }
         void set_live_sec( time_t sec ){ m_live_sec = sec; }
 
+        // 最終アクセス時刻
+        const time_t get_last_access_time() const{ return m_last_access_time; }
+
         // 最大レス数
         const int get_number_max_res() const{ return m_number_max_res; }
         void set_number_max_res( const int number ){ m_number_max_res = number; }
