@@ -14,6 +14,8 @@
 
 #include "dbimg/imginterface.h"
 
+#include "message/logmanager.h"
+
 #include "config/globalconf.h"
 
 #include "global.h"
@@ -62,9 +64,11 @@ NodeTreeBase::NodeTreeBase( const std::string url, const std::string& modified )
       m_resume ( 0 ),
       m_broken( 0 ),
       m_heap( SIZE_OF_HEAP ),
-      m_buffer_lines( 0 ),
-      m_parsed_text( 0 ),
+      m_buffer_lines( NULL ),
+      m_parsed_text( NULL ),
+      m_buffer_write( NULL ),
       m_check_update( false ),
+      m_check_write( false ),
       m_fout ( 0 )
 {
     set_date_modified( modified );
@@ -139,12 +143,19 @@ void NodeTreeBase::update_url( const std::string& url )
 //
 void NodeTreeBase::clear()
 {
+#ifdef _DEBUG    
+    std::cout << "NodeTreeBase::clear : " << m_url << std::endl;
+#endif
+
     if( m_buffer_lines ) free( m_buffer_lines );
     m_buffer_lines = NULL;
     m_byte_buffer_lines_left = 0;
 
     if( m_parsed_text ) free( m_parsed_text );
     m_parsed_text = NULL;
+
+    if( m_buffer_write ) free( m_buffer_write );
+    m_buffer_write = NULL;
     
     if( m_fout ) fclose( m_fout );
     m_fout = NULL;
@@ -613,10 +624,10 @@ std::list< int > NodeTreeBase::get_res_name( const std::string& name )
 
 
 //
-// number番のレスの時刻
+// number番のレスの時刻を文字列で取得
 // 内部で regex　を使っているので遅い
 //
-const std::string NodeTreeBase::get_time( int number )
+const std::string NodeTreeBase::get_time_str( int number )
 {
     std::string res_str = get_res_str( number );
     if( res_str.empty() ) return std::string();
@@ -624,7 +635,7 @@ const std::string NodeTreeBase::get_time( int number )
     std::string time_str;
     JDLIB::Regex regex;
 
-    if( regex.exec( " 名前：.+]：([0-9]*/[0-9]*/[0-9]*[^ ]* [0-9]*:[0-9]*[^ ]*).*$", res_str ) ){
+    if( regex.exec( " 名前：.+]： +([0-9]*/[0-9]*/[0-9]*[^ ]* [0-9]*:[0-9]*[^ ]*).*$", res_str ) ){
         time_str = regex.str( 1 );
     }
 
@@ -721,6 +732,17 @@ NODE* NodeTreeBase::createBrNode()
 }
 
 
+//
+// 水平線ノード作成
+//
+NODE* NodeTreeBase::createHrNode()
+{
+    NODE* tmpnode = createNode();
+    tmpnode->type = NODE_HR;
+    return tmpnode;
+}
+
+
 //
 // スペースノード
 //
@@ -888,10 +910,11 @@ void NodeTreeBase::load_cache()
             const char* data = str.data();
             size_t size = 0;
             m_check_update = false;
+            m_check_write = false;
             init_loading();
             const size_t str_length = str.length();
             while( size < str_length ){
-                size_t size_tmp = MIN( MAXSISE_OF_LINES, str_length - size );
+                size_t size_tmp = MIN( MAXSISE_OF_LINES - m_byte_buffer_lines_left, str_length - size );
                 receive_data( data + size, size_tmp );
                 size += size_tmp;
             }
@@ -904,8 +927,6 @@ void NodeTreeBase::load_cache()
 //
 // ロード実行前に呼ぶ初期化関数
 //
-// charcode は入力データの文字コード( empty()ならコード変換しない)
-//
 void NodeTreeBase::init_loading()
 {
     clear();
@@ -913,6 +934,7 @@ void NodeTreeBase::init_loading()
     // 一時バッファ作成
     if( ! m_buffer_lines ) m_buffer_lines = ( char* ) malloc( MAXSISE_OF_LINES ); 
     if( ! m_parsed_text ) m_parsed_text = ( char* ) malloc( MAXSISE_OF_LINES );
+    if( m_check_write && ! m_buffer_write ) m_buffer_write = ( char* ) malloc( MAXSISE_OF_LINES ); 
 }
 
 
@@ -920,16 +942,22 @@ void NodeTreeBase::init_loading()
 //
 // ロード開始
 //
+// check_update : HEADによる更新チェックのみ
+//
 void NodeTreeBase::download_dat( const bool check_update )
 {
-#ifdef _DEBUG    
-    std::cout << "NodeTreeBase::download_dat : " << m_url << " lng = " << m_lng_dat << std::endl
-              << "modified = " << date_modified() << " check_update = " << check_update << std::endl;
-#endif
-
     if( is_loading() ) return;
 
     m_check_update = check_update;
+    m_check_write = false;
+    if( ! m_check_update ) m_check_write = MESSAGE::get_log_manager()->has_items( m_url, ! get_res_number() );
+
+#ifdef _DEBUG    
+    std::cout << "NodeTreeBase::download_dat : " << m_url << " lng = " << m_lng_dat << std::endl
+              << "modified = " << date_modified() << " check_update = " << check_update
+              << " check_write = " << m_check_write << std::endl;
+#endif
+
 
     // オフライン
     if( ! SESSION::is_online() ){
@@ -1066,7 +1094,10 @@ void NodeTreeBase::receive_finish()
     if( ! m_check_update ){
 
         // Requested Range Not Satisfiable
-        if( get_code() == HTTP_RANGE_ERR ) m_broken = true;
+        if( get_code() == HTTP_RANGE_ERR ){
+            m_broken = true;
+            MISC::ERRMSG( "Requested Range Not Satisfiable" );
+        }
 
         // データがロードされなかったらキャッシュを消す
         if( get_res_number() == 0 ){
@@ -1078,6 +1109,14 @@ void NodeTreeBase::receive_finish()
 
         // その他、何かエラーがあったらmodifiedをクリアしておく
         if( !get_ext_err().empty() ) set_date_modified( std::string() );
+
+        // 書き込みチェック終了
+        if( m_check_write
+            && ( get_code() == HTTP_OK
+                 || get_code() == HTTP_PARTIAL_CONTENT
+                 || get_code() == HTTP_NOT_MODIFIED
+                )
+            ) MESSAGE::get_log_manager()->remove_items( m_url );
     }
 
 #ifdef _DEBUG
@@ -1103,7 +1142,6 @@ void NodeTreeBase::add_raw_lines( char* rawlines, size_t size )
     for( size_t i = 0; i < size; ++i ){
         if( rawlines[ i ] == '\0' ){
             MISC::ERRMSG( "EOF was inserted in the middle of the raw data" );
-            m_broken = true;
             rawlines[ i ] = ' ';
         } 
     }
@@ -1238,6 +1276,31 @@ const char* NodeTreeBase::add_one_dat_line( const char* datline )
 #endif
     }
 
+    // 自分の書き込みかチェック
+    if( m_check_write ){
+
+        // 簡易チェック
+        // 最初の lng_check 文字だけ見る
+        const bool newthread = ( header->id_header == 1 );
+        const int lng_check = MIN( section_lng[ 3 ], 32 );
+        parse_write( section[ 3 ], section_lng[ 3 ], lng_check );
+        if( MESSAGE::get_log_manager()->check_write( m_url, newthread, m_buffer_write, lng_check ) ){
+
+            // 全ての文字列で一致しているかチェック
+            parse_write( section[ 3 ], section_lng[ 3 ], 0 );
+
+            const bool hit = MESSAGE::get_log_manager()->check_write( m_url, newthread, m_buffer_write, 0 );
+            if( hit ){
+                if( ! m_vec_posted.size() ) m_vec_posted.resize( MAX_RESNUMBER );
+                m_vec_posted[ header->id_header ] = true;
+            }
+
+#ifdef _DEBUG
+            std::cout << "check_write id = " << header->id_header << " hit = " << hit << std::endl;
+#endif
+        }
+    }
+
     return pos;
 }
 
@@ -1249,9 +1312,6 @@ void NodeTreeBase::parseName( NODE* header, const char* str, int lng, int color_
 {
     bool digitlink = true;
     const bool bold = true;
-    int pos_trip_begin = 0;
-    int pos_trip_end = 0;
-    int i;
     const bool defaultname = ( strncmp( m_default_noname.data(), str, lng ) == 0 );
 
     header->headinfo->block[ BLOCK_NAMELINK ] = create_block_node();
@@ -1265,59 +1325,78 @@ void NodeTreeBase::parseName( NODE* header, const char* str, int lng, int color_
 
     NODE* node = header->headinfo->block[ BLOCK_NAME ] = create_block_node();
 
-    // トリップなど</b>〜<b>が含まれている場合。</b>〜<b>の中の数字はリンクにしない
-    for( i = 0; i < lng; ++i ) if( str[ i ] == '<' && ( str[ i+2 ] == 'b' || str[ i+2 ] == 'B' ) ) break;
-    if( i != lng ){
-
-        pos_trip_begin = i;
-        pos_trip_end = lng -1;
-        for( i = pos_trip_begin + 4; i < lng; ++i ){
-                if( str[ i ] == '<' && ( str[ i+1 ] == 'b' || str[ i+1 ] == 'B' ) ){
-                pos_trip_end = i + 2;
-                break;
-            }
-        }
-
-#ifdef _DEBUG        
-        char tmp_str[256];
-        memset( tmp_str, 0, 256);
-        memcpy(tmp_str, str, lng);
-
-        std::cout << "NodeTreeBase::parseName trip = " << tmp_str
-                  << " begin = " << pos_trip_begin << " end = " << pos_trip_end << std::endl;
-#endif
-        // トリップの前(名前部分)
-        parse_html( str, pos_trip_begin, color_name, digitlink, bold );
-
-        // あとは数字が入ってもリンクしない
-        digitlink = false;
-
-        // トリップ
-        parse_html( str + pos_trip_begin, pos_trip_end - pos_trip_begin + 1, COLOR_CHAR_NAME_B, digitlink, bold );
-
-        // トリップの後
-        if( pos_trip_end < lng-1 )
-            parse_html( str + pos_trip_end + 1, lng - pos_trip_end - 1, color_name, digitlink, bold );
-    }
-
     // デフォルト名無しと同じときはアンカーを作らない
-    else if( defaultname ){
+    if( defaultname ){
         digitlink = false;
         parse_html( str, lng, color_name, digitlink, bold );
     }
+    else{
 
-    // 通常の場合は先頭に数字があったらアンカーにする
-    else parse_html( str, lng, color_name, digitlink, bold );
+        int pos = 0;
+        int i;
+
+        while( pos < lng ){
+
+            // トリップなど</b>〜<b>の中の文字列は色を変えて数字をリンクにしない
+            for( i = pos; i < lng; ++i ){
+                if( str[ i ] == '<'
+                    && str[ i+1 ] == '/'
+                    && ( str[ i+2 ] == 'b' || str[ i+2 ] == 'B' )
+                    && str[ i+3 ] == '>' ) break;
+            }
+
+            // </b>の前までパース
+            if( i != pos ){
+                digitlink = true;
+                parse_html( str + pos, i - pos, color_name, digitlink, bold );
+            }
+            if( i >= lng ) break;
+            pos = i + 4; // 4 = strlen( "</b>" );
+
+            // <b>の位置を探す
+            int pos_end = lng;
+            for( i = pos; i < lng; ++i ){
+                if( str[ i ] == '<'
+                    && ( str[ i+1 ] == 'b' || str[ i+1 ] == 'B' )
+                    && str[ i+2 ] == '>' ){
+                    pos_end = i;
+                    break;
+                }
+            }
+
+#ifdef _DEBUG        
+            char tmp_str[256];
+            memset( tmp_str, 0, 256);
+            memcpy( tmp_str, str + pos, pos_end - pos );
+
+            std::cout << "NodeTreeBase::parseName trip = " << tmp_str
+                      << " begin = " << pos << " end = " << pos_end << std::endl;
+#endif
+
+            // </b><b>の中をパース
+            digitlink = false; // 数字が入ってもリンクしない
+            parse_html( str + pos, pos_end - pos, COLOR_CHAR_NAME_B, digitlink, bold );
+
+            pos = pos_end + 3; // 3 = strlen( "<b>" );
+        }
+    }
 
     // plainな名前取得
-    std::string str_tmp;
-    node = node->next_node;
-    while( node ){
-        if( node->text ) str_tmp += node->text;
+    // 名前あぼーんや名前抽出などで使用する
+    if( defaultname ){
+        header->headinfo->name = ( char* )m_heap.heap_alloc( lng +2 );
+        memcpy( header->headinfo->name, str, lng );
+    }
+    else{
+        std::string str_tmp;
         node = node->next_node;
+        while( node ){
+            if( node->text ) str_tmp += node->text;
+            node = node->next_node;
+        }
+        header->headinfo->name = ( char* )m_heap.heap_alloc( str_tmp.length() +2 );
+        memcpy( header->headinfo->name, str_tmp.c_str(), str_tmp.length() );
     }
-    header->headinfo->name = ( char* )m_heap.heap_alloc( str_tmp.length() +2 );
-    memcpy( header->headinfo->name, str_tmp.c_str(), str_tmp.length() );
 }
 
 
@@ -1505,13 +1584,20 @@ void NodeTreeBase::parse_html( const char* str, int lng, int color_text, bool di
 
                 while( pos < pos_end && *pos != '=' ) ++pos;
                 ++pos;
-                if( *pos == '"' || *pos == ' ' ) ++pos;
+
+                if( *pos == ' ' ) ++pos;
                 if( pos >= pos_end ) continue;
 
+                bool dbq = false;
+                if( *pos == '"' ){
+                    dbq = true;
+                    ++pos;
+                }
+
                 const char* pos_link_start = pos;
                 int lng_link = 0;
 
-                while( pos < pos_end && ( *pos != '"' && *pos != ' ' && *pos != '>' ) ){ ++pos; ++lng_link; }
+                while( pos < pos_end && ( ( ( dbq && *pos != '"' ) || ( !dbq && *pos != ' ' ) ) && *pos != '>' ) ){ ++pos; ++lng_link; }
                 if( pos >= pos_end ) continue;
 
                 while( pos < pos_end && *pos != '>' ) ++pos;
@@ -1592,6 +1678,19 @@ void NodeTreeBase::parse_html( const char* str, int lng, int color_text, bool di
                 lng_text += n_out;
             }
 
+            // 水平線 <HR>
+            else if( ( *( pos + 1 ) == 'h' || *( pos + 1 ) == 'H' )
+                     && ( *( pos + 2 ) == 'r' || *( pos + 2 ) == 'R' ) ){
+
+                // フラッシュ
+                createTextNodeN( m_parsed_text, lng_text, color_text, bold ); lng_text = 0;
+
+                // 水平線ノード作成
+                createHrNode();
+
+                pos += 4;
+            }
+
             // その他のタグは無視。タグを取り除いて中身だけを見る
             else {
 
@@ -1749,6 +1848,68 @@ void NodeTreeBase::parse_html( const char* str, int lng, int color_text, bool di
 }
 
 
+//
+// 書き込みログ比較用文字列作成
+//
+// max_lng_write > 0 のときは m_buffer_write の文字数が max_lng_write 以上になったら停止
+//
+void NodeTreeBase::parse_write( const char* str, const int lng, const int max_lng_write )
+{
+    if( ! m_buffer_write ) return;
+
+    const char* pos = str;
+    const char* pos_end = str + lng;
+
+    char* pos_write = m_buffer_write;
+
+    // 行頭の空白は全て除く
+    while( *pos == ' ' ) ++pos;
+    
+    for( ; pos < pos_end
+         && ( max_lng_write == 0 || (int)( pos_write - m_buffer_write ) < max_lng_write )
+         ; ++pos ){
+
+        // タグ
+        if( *pos == '<' ){ 
+
+            // <br>
+            if( ( *( pos + 1 ) == 'b' || *( pos + 1 ) == 'B' )
+                && ( *( pos + 2 ) == 'r' || *( pos + 2 ) == 'R' )
+                ){
+                *(pos_write++) = '\n';
+                pos += 3;
+            }
+
+            // その他のタグは無視
+            else while( pos < pos_end && *pos != '>' ) ++pos;
+
+            continue;
+        }
+
+        // gt
+        else if( *pos == '&' && ( *( pos + 1 ) == 'g' && *( pos + 2 ) == 't' && *( pos + 3 ) == ';' ) ){
+
+            *(pos_write++) = '>';
+            pos += 3;
+
+            continue;
+        }
+
+        // lt
+        else if( *pos == '&' && ( *( pos + 1 ) == 'l' && *( pos + 2 ) == 't' && *( pos + 3 ) == ';' ) ){
+
+            *(pos_write++) = '<';
+            pos += 3;
+
+            continue;
+        }
+
+        *(pos_write++) = *pos;
+    }
+
+    *pos_write = '\0';
+}
+
 
 //
 // アンカーが現れたかチェックして文字列を取得する関数
@@ -1917,7 +2078,7 @@ bool NodeTreeBase::check_link( const char* str_in, int lng_in, int& n_in, char*
 
     // http://, https://, ftp://, ttp(s)://, tp(s):// のチェック
     int delim_pos = 0;
-    int linktype = MISC::is_url_scheme( str_in, delim_pos );
+    int linktype = MISC::is_url_scheme( str_in, &delim_pos );
 
     if( linktype == MISC::SCHEME_NONE ) return false;
 
@@ -2043,8 +2204,8 @@ void NodeTreeBase::copy_abone_info( std::list< std::string >& list_abone_id,
                                     std::list< std::string >& list_abone_name,
                                     std::list< std::string >& list_abone_word,
                                     std::list< std::string >& list_abone_regex,
-                                    std::vector< char >& vec_abone_res,
-                                    bool& abone_transparent, bool& abone_chain )
+                                    const std::vector< char >& vec_abone_res,
+                                    const bool abone_transparent, const bool abone_chain )
 {
     m_list_abone_id = list_abone_id;
     m_list_abone_name = list_abone_name;
@@ -2448,6 +2609,8 @@ void NodeTreeBase::check_reference( int number )
     bool checked[ number ];
     memset( checked, 0, sizeof( bool ) * number );
 
+    const bool posted = m_vec_posted.size();
+
     for( int block = 0; block < BLOCK_NUM; ++block ){
 
         NODE* node = head->headinfo->block[ block ];
@@ -2489,6 +2652,16 @@ void NodeTreeBase::check_reference( int number )
 
                                 checked[ i ] = true;
 
+                                // 自分の書き込みに対するレス
+                                if( posted && m_vec_posted[ i ] ){
+                                    if( ! m_vec_refer_posted.size() ) m_vec_refer_posted.resize( MAX_RESNUMBER );
+                                    m_vec_refer_posted[ number ] = true;
+
+#ifdef _DEBUG
+                                    std::cout << "ref " << i << " " << number << std::endl;
+#endif
+                                }
+
                                 // 参照数を更新して色を変更
                                 ++( tmphead->headinfo->num_reference );
 
@@ -2642,3 +2815,13 @@ bool NodeTreeBase::remove_imenu( char* str_link )
 
     return false;
 }
+
+
+// 自分の書き込みにレスしたか
+const bool NodeTreeBase::is_refer_posted( const int number )
+{
+    if( ! m_vec_refer_posted.size() ) return false;
+    if( m_vec_refer_posted.size() <= ( size_t )number ) return false;
+
+    return m_vec_refer_posted[ number ];
+}
