@@ -21,6 +21,7 @@
 #include "command.h"
 #include "sharedbuffer.h"
 #include "global.h"
+#include "type.h"
 #include "controlutil.h"
 #include "controlid.h"
 #include "prefdiagfactory.h"
@@ -909,10 +910,11 @@ void ImageViewBase::slot_open_ref()
 {
     if( ! m_enable_menuslot ) return;
 
-    std::string refurl = m_img->get_refurl();
+    const std::string refurl = m_img->get_refurl();
 
     int center, from, to;
-    std::string url = DBTREE::url_dat( refurl, center, to );
+    std::string num_str;
+    const std::string url = DBTREE::url_dat( refurl, center, to, num_str );
     if( url.empty() ) return;
 
     const int range = 10;
@@ -1104,7 +1106,7 @@ void ImageViewBase::activate_act_before_popupmenu( const std::string& url )
     // 削除
     act = action_group()->get_action( "DeleteMenu" );
     if( act ){
-        if( ( m_img->is_cached() || m_img->get_type() == DBIMG::T_LARGE ) && ! m_img->is_protected() ) act->set_sensitive( true );
+        if(  m_img->get_code() != HTTP_INIT && ! m_img->is_protected() ) act->set_sensitive( true );
         else act->set_sensitive( false );
     }
 
