@@ -7,6 +7,7 @@
 #include "skeleton/editview.h"
 #include "skeleton/imgbutton.h"
 #include "skeleton/compentry.h"
+#include "skeleton/jdtoolbar.h"
 
 namespace JDLIB
 {
@@ -16,6 +17,7 @@ namespace JDLIB
 
 namespace SKELETON
 {
+    class Admin;
     class LabelEntry;
 }
 
@@ -23,7 +25,6 @@ namespace SKELETON
 namespace MESSAGE
 {
     class Post;
-    class MessageToolBar;
 
     class MessageViewBase : public SKELETON::View
     {
@@ -34,23 +35,29 @@ namespace MESSAGE
         Gtk::Notebook m_notebook;
         SKELETON::View* m_preview;
         Gtk::VBox m_msgview;
-        
-        Gtk::HBox m_hbox_name_mail;
+
+        SKELETON::JDToolbar m_toolbar_name_mail;
+
+        Gtk::ToolItem m_tool_name;
+        Gtk::ToolItem m_tool_mail;
+        Gtk::ToolItem m_tool_fixname;
+        Gtk::ToolItem m_tool_fixmail;
+        Gtk::ToolItem m_tool_entry_name;
+        Gtk::ToolItem m_tool_entry_mail;
+
         Gtk::Label m_label_name;
         Gtk::Label m_label_mail;
         Gtk::CheckButton m_check_fixname;
         Gtk::CheckButton m_check_fixmail;
+        SKELETON::CompletionEntry m_entry_name;
+        SKELETON::CompletionEntry m_entry_mail;
 
-        bool m_enable_menuslot;
-        bool m_enable_focus;
-
-        SKELETON::NameEntry m_entry_name;
-        SKELETON::MailEntry m_entry_mail;
         SKELETON::EditView m_text_message;
 
+        bool m_enable_focus;
+
         // 文字数計算用
         JDLIB::Iconv* m_iconv;
-        char* m_str_iconv;
         int m_max_line;
         int m_max_str;
         int m_lng_str_enc;
@@ -71,8 +78,12 @@ namespace MESSAGE
         // コマンド
         virtual bool set_command( const std::string& command, const std::string& arg = std::string() );
 
+        // ロード中
+        virtual const bool is_loading();
+
         // SKELETON::View の関数のオーバロード
         virtual void clock_in();
+        virtual void write();
         virtual void reload(){}
         virtual void relayout();
         virtual void close_view();
@@ -88,22 +99,24 @@ namespace MESSAGE
         // 色初期化
         void init_color();
 
+        // 自分の書き込みの判定用データの保存
+        void push_logitem();
+
         // 書き込みログ保存
         void save_postlog();
 
-        virtual void write() = 0;
+        // 実際の書き込み処理を行う関数(子クラス別に実装)
+        virtual void write_impl() = 0;  
+
+        // プレビュー切り替え
+        void toggle_preview();
 
         void tab_left();
         void tab_right();
 
-        void focus_writebutton();
+        // 下書きファイル挿入
+        void insert_draft();
 
-        void slot_write_clicked();
-        void slot_close_clicked();
-        void slot_draft_open();
-        void slot_undo_clicked();
-        void slot_not_close_clicked();
-        void slot_preview_clicked();
         bool slot_key_press( GdkEventKey* event );
         bool slot_button_press( GdkEventButton* event );
         void slot_switch_page( GtkNotebookPage*, guint page );
@@ -114,12 +127,12 @@ namespace MESSAGE
 
       protected:
 
+        // Viewが所属するAdminクラス
+        virtual SKELETON::Admin* get_admin();
+
         void set_message( const std::string& msg ){ m_text_message.set_text( msg ); }
         Glib::ustring get_message(){ return m_text_message.get_text(); }
 
-        MessageToolBar* get_messagetoolbar();
-
-        SKELETON::LabelEntry* get_entry_subject();
         SKELETON::CompletionEntry& get_entry_name(){ return m_entry_name; }
         SKELETON::CompletionEntry& get_entry_mail(){ return m_entry_mail; }
         SKELETON::EditView& get_text_message() { return m_text_message; }
