@@ -19,6 +19,8 @@ namespace CORE
         PREFDIAG_PASSWD,
         PREFDIAG_PRIVARY,
         PREFDIAG_BROWSER,
+        PREFDIAG_LINKFILTER,
+        PREFDIAG_USRCMD,
         PREFDIAG_PROXY,
         PREFDIAG_GLOBALABONETHREAD,
         PREFDIAG_GLOBALABONE,
