@@ -30,11 +30,16 @@ namespace CORE
         VIEW_ARTICLENAME,
         VIEW_ARTICLEID,
         VIEW_ARTICLEBM,
+        VIEW_ARTICLEPOST,
         VIEW_ARTICLEURL,
         VIEW_ARTICLEREFER,
         VIEW_ARTICLEDRAWOUT,
         VIEW_ARTICLEPREVIEW,
-        VIEW_ARTICLESEARCHCAHCE,
+        VIEW_ARTICLEINFO,
+        VIEW_ARTICLESEARCHLOG,
+        VIEW_ARTICLESEARCHALLLOG,
+        VIEW_ARTICLESEARCHTITLE,
+        VIEW_ARTICLEPOSTLOG,
 
         VIEW_ARTICLEPOPUPHTML,
         VIEW_ARTICLEPOPUPRES,
